@@ -13,7 +13,7 @@ class ListTemplateAnnotationsResponse(BaseModel):
     :type annotations: List[Annotation], optional
     """
 
-    def __init__(self, annotations: List[Annotation] = None):
+    def __init__(self, annotations: List[Annotation] = None, **kwargs):
         """ListTemplateAnnotationsResponse
 
         :param annotations: annotations, defaults to None
@@ -21,3 +21,4 @@ class ListTemplateAnnotationsResponse(BaseModel):
         """
         if annotations is not None:
             self.annotations = self._define_list(annotations, Annotation)
+        self._kwargs = kwargs
