@@ -14,7 +14,7 @@ class ListWebhooksRequest(BaseModel):
     :type event: WebhookEvent, optional
     """
 
-    def __init__(self, webhook_id: str = None, event: WebhookEvent = None):
+    def __init__(self, webhook_id: str = None, event: WebhookEvent = None, **kwargs):
         """ListWebhooksRequest
 
         :param webhook_id: ID of the webhook, defaults to None
@@ -26,3 +26,4 @@ class ListWebhooksRequest(BaseModel):
             self.webhook_id = webhook_id
         if event is not None:
             self.event = self._enum_matching(event, WebhookEvent.list(), "event")
+        self._kwargs = kwargs
