@@ -1,3 +1,4 @@
+from typing import Union
 from .services.signplus import SignplusService
 from .net.environment import Environment
 
@@ -6,21 +7,32 @@ class Signplus:
     def __init__(
         self,
         access_token: str = None,
-        base_url: str = Environment.DEFAULT.value,
+        base_url: Union[Environment, str] = Environment.DEFAULT,
         timeout: int = 60000,
     ):
         """
         Initializes Signplus the SDK class.
         """
-        self.signplus = SignplusService(base_url=base_url)
+
+        self._base_url = (
+            base_url.value if isinstance(base_url, Environment) else base_url
+        )
+        self.signplus = SignplusService(base_url=self._base_url)
         self.set_access_token(access_token)
         self.set_timeout(timeout)
 
-    def set_base_url(self, base_url):
+    def set_base_url(self, base_url: Union[Environment, str]):
         """
         Sets the base URL for the entire SDK.
+
+        :param Union[Environment, str] base_url: The base URL to be set.
+        :return: The SDK instance.
         """
-        self.signplus.set_base_url(base_url)
+        self._base_url = (
+            base_url.value if isinstance(base_url, Environment) else base_url
+        )
+
+        self.signplus.set_base_url(self._base_url)
 
         return self
 
